@@ -24,7 +24,7 @@ PUSHES_BLOCK = 2048  # starts a block (while, try, finally, with, etc.)
 POPS_BLOCK = 4096  # ends a block
 
 
-class Opcode(object):
+class Opcode:
   """An opcode without arguments."""
 
   __slots__ = ("line", "index", "prev", "next", "target", "block_target",
@@ -138,7 +138,7 @@ class OpcodeWithArg(Opcode):
   __slots__ = ("arg", "pretty_arg")
 
   def __init__(self, index, line, arg, pretty_arg):
-    super(OpcodeWithArg, self).__init__(index, line)
+    super().__init__(index, line)
     self.arg = arg
     self.pretty_arg = pretty_arg
 
@@ -324,7 +324,14 @@ class BEGIN_FINALLY(Opcode):
 
 
 class END_ASYNC_FOR(Opcode):
-  FLAGS = HAS_JUNKNOWN | NO_NEXT  # might re-raise an exception
+  # Even though dis documentation says that END_ASYNC_FOR may reraise an
+  # exception, we do not include NO_NEXT in the flags because doing so would
+  # cause the return statement for an async method to be skipped, leading to
+  # an incorrect return type.
+  # See tests/py3/test_stdlib:StdlibTestsFeatures.test_async_iter and
+  # tests/py3/test_coroutine:GeneratorFeatureTest.test_async_for_pyi for tests
+  # that fail if we add NO_NEXT.
+  FLAGS = HAS_JUNKNOWN
   __slots__ = ()
 
 
@@ -1098,7 +1105,7 @@ python_3_5_mapping = {
 def _overlay_mapping(mapping, new_entries):
   ret = mapping.copy()
   ret.update(new_entries)
-  return dict((k, v) for k, v in six.iteritems(ret) if v is not None)
+  return dict((k, v) for k, v in ret.items() if v is not None)
 
 python_3_6_mapping = _overlay_mapping(python_3_5_mapping, {
     85: SETUP_ANNOTATIONS,
@@ -1130,7 +1137,7 @@ python_3_8_mapping = _overlay_mapping(python_3_7_mapping, {
 })
 
 
-class _LineNumberTableParser(object):
+class _LineNumberTableParser:
   """State machine for decoding a Python line number array."""
 
   def __init__(self, python_version, lnotab, firstlineno):
